@@ -1,5 +1,5 @@
 /*****************************************************************************\
- *  $Id: err.c 1009 2006-02-14 16:11:43Z grondo $
+ *  $Id: err.c 1104 2006-12-08 00:39:49Z grondo $
  *****************************************************************************
  *  Copyright (C) 2001-2006 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
@@ -49,6 +49,11 @@
 static char *prog = NULL;
 static char *host = NULL;
 
+/*
+ * Optionally leave domain on hostnames with _verr's %S
+ */
+static bool keep_host_domain = false;
+
 /*
  * Call this before calling err() or errx().  Sets hostname and program name 
  * for %H, %p, and %P.
@@ -66,6 +71,11 @@ void err_init(char *str)
     prog = Strdup(str);
 }
 
+void err_no_strip_domain ()
+{
+    keep_host_domain = true;
+}
+
 /*
  * Free heap storage allocated by err_init()
  */
@@ -105,8 +115,9 @@ static void _verr(FILE * stream, char *format, va_list ap)
                 xstrcat(&buf, va_arg(ap, char *));
             } else if (*format == 'S') {        /* %S - string, trunc */
                 snprintf(tmpstr, sizeof(tmpstr), "%s", va_arg(ap, char *));
-                if (!isdigit(*tmpstr)
-                    && (q = strchr(tmpstr, '.')))
+                if (  !isdigit(*tmpstr) 
+                   && !keep_host_domain 
+                   && (q = strchr(tmpstr, '.')))
                     *q = '\0';
                 xstrcat(&buf, tmpstr);
             } else if (*format == 'z') {        /* %z - same as %.3d */
