@@ -1,5 +1,5 @@
 /*****************************************************************************\
- *  $Id: mcmd.c 1009 2006-02-14 16:11:43Z grondo $
+ *  $Id: mcmd.c 1151 2008-01-29 17:45:54Z grondo $
  *****************************************************************************
  *  Copyright (C) 2001-2006 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
@@ -329,6 +329,9 @@ mcmd(char *ahost, char *addr, char *locuser, char *remuser, char *cmd,
     munge_ctx_t ctx;
     struct xpollfd xpfds[2];
 
+    memset (xpfds, 0, sizeof (xpfds));
+    memset (&sin, 0, sizeof (sin));
+
     sigemptyset(&blockme);
     sigaddset(&blockme, SIGURG);
     sigaddset(&blockme, SIGPIPE);
@@ -498,7 +501,8 @@ mcmd(char *ahost, char *addr, char *locuser, char *remuser, char *cmd,
     if ((rv = munge_encode(&m,ctx,mbuf,mcount)) != EMUNGE_SUCCESS) {
         err("%p: %S: mcmd: munge_encode: %s\n", ahost, munge_ctx_strerror(ctx));
         munge_ctx_destroy(ctx);
-        close(s2);
+        if (s2 >= 0) 
+            close(s2);
         free(tmbuf);
         goto bad;
     }
