@@ -1,5 +1,5 @@
 /*****************************************************************************\
- *  $Id: opt.c 1125 2007-06-04 17:27:56Z grondo $
+ *  $Id: opt.c 1156 2008-03-19 17:50:50Z grondo $
  *****************************************************************************
  *  Copyright (C) 2001-2006 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
@@ -362,6 +362,21 @@ void opt_default(opt_t * opt, char *argv0)
     return;
 }
 
+static int string_to_int (const char *val, int *p2int)
+{
+    char *p;
+    long n;
+
+    errno = 0;
+    n = strtoul (val, &p, 10);
+    if (errno || (*p != '\0'))
+        return (-1);
+
+    *p2int = (int) n;
+
+    return (0);
+}
+
 /*
  * Override default options with environment variables.
  *	opt (IN/OUT)	option struct	
@@ -370,11 +385,9 @@ void opt_env(opt_t * opt)
 {
     char *rhs;
 
-    if ((rhs = getenv("WCOLL")) != NULL)
-        opt->wcoll = read_wcoll(rhs, NULL);
-
     if ((rhs = getenv("FANOUT")) != NULL)
-        opt->fanout = atoi(rhs);
+        if (string_to_int (rhs, &opt->fanout) < 0)
+            errx ("%p: Invalid environment variable FANOUT=%s\n", rhs);
 
     if ((rhs = getenv("PDSH_RCMD_TYPE")) != NULL)
         opt->rcmd_name = Strdup(rhs);
@@ -409,7 +422,6 @@ static void wcoll_append (opt_t *opt, char *hosts);
  */
 void opt_args(opt_t * opt, int argc, char *argv[])
 {
-    int wcoll_count = 0;
     int c;
     extern int optind;
     extern char *optarg;
@@ -437,20 +449,14 @@ void opt_args(opt_t * opt, int argc, char *argv[])
             opt->debug = true;
             break;
         case 'f':              /* fanout */
-            opt->fanout = atoi(optarg);
+            if (string_to_int (optarg, &opt->fanout) < 0)
+                errx ("%p: Invalid fanout `%s' passed to -f.\n", optarg);
             break;
         case 'w':              /* target node list */
             if (strcmp(optarg, "-") == 0)
                 opt->wcoll = read_wcoll(NULL, stdin);
-            else { 
-                /* Throw  away contents of WCOLL file if they exist 
-                 */
-                if (!(wcoll_count++) && opt->wcoll) {
-                    hostlist_destroy (opt->wcoll);
-                    opt->wcoll = NULL;
-                }
+            else 
                 wcoll_append(opt, optarg);
-            }
             break;
         case 'x':              /* exclude node list */
             exclude_buf = Strdup(optarg);
@@ -573,14 +579,23 @@ void opt_args(opt_t * opt, int argc, char *argv[])
     }
 
     /* ignore wcoll & -x option if we are running pcp server */
-    if (!opt->pcp_server) {
+    if (opt->pcp_server) 
+        return;
 
-        /*
-         *  Attempt to grab wcoll from modules stack unless
-         *    wcoll was set from -w.
-         */
-        if (mod_read_wcoll(opt) < 0)
-            exit(1);
+    /*
+     *  Attempt to grab wcoll from modules stack unless
+     *    wcoll was set from -w.
+     */
+    if (mod_read_wcoll(opt) < 0)
+        exit(1);
+
+    /*
+     *  If wcoll is still empty, try WCOLL environment variable.
+     */
+    if (!opt->wcoll) {
+        char *val;
+        if ((val = getenv("WCOLL")) != NULL)
+            opt->wcoll = read_wcoll(val, NULL);
     }
 }
 
@@ -689,7 +704,7 @@ bool opt_verify(opt_t * opt)
         }
 
         /* If reverse copy, the destination must be a directory */
-        if (opt->reverse_copy) {
+        if (opt->reverse_copy && opt->outfile_name) {
             struct stat statbuf;
 
             if (stat(opt->outfile_name, &statbuf) < 0) {
@@ -754,7 +769,7 @@ bool opt_verify(opt_t * opt)
         }
 
         /* If reverse copy the infiles should exist locally */
-        if (!_infile_names_check(opt))
+        if (opt->infile_names && !_infile_names_check(opt))
             verified = false;
     }
 
@@ -959,8 +974,6 @@ static int get_host_rcmd_type (char *hosts, char **rptr, char **hptr,
 {
     char *p = hosts;
     char *q;
-    *uptr = NULL;
-    *rptr = NULL;
     *hptr = hosts;
 
     p = strchr (hosts, ':');
@@ -999,7 +1012,7 @@ static void wcoll_append (opt_t *opt, char *str)
         opt->wcoll = hostlist_create (NULL);
 
     while ((tok = hostlist_shift (hl))) {
-        char *hosts, *user;
+        char *hosts, *user = NULL;
 
         get_host_rcmd_type (tok, &rcmd_type, &hosts, &user);
 
