@@ -1,5 +1,5 @@
 /*****************************************************************************\
- *  $Id: opt.h 1009 2006-02-14 16:11:43Z grondo $
+ *  $Id: opt.h 1125 2007-06-04 17:27:56Z grondo $
  *****************************************************************************
  *  Copyright (C) 2001-2006 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
@@ -87,7 +87,10 @@ typedef struct {
     char *outfile_name;         /* pcp dest spec */
     bool pcp_server;            /* undocument pdcp server option */
     bool target_is_directory;   /* undocumented pdcp is target a directory */
+    bool pcp_client;            /* undocumented pdcp client option */
+    char *pcp_client_host;      /* hostname used to execute client */
     char *path_progname;        /* absolute path to program name */
+    bool reverse_copy;          /* rpdcp: reverse copy */
 } opt_t;
 
 
@@ -104,6 +107,16 @@ void opt_free(opt_t *);
 pers_t pdsh_personality(void);
 
 
+/*
+ *  Return a list of the original remote args
+ */
+char ** pdsh_remote_argv (void);
+
+/*
+ *  Return a list of the original remote arg count
+ */
+int pdsh_remote_argc (void);
+
 /*
  * Structure for pdsh modules to export new options. 
  * 
